#!/bin/sh
### BEGIN INIT INFO
# Provides:          BubbleUPnP-daemon
# Required-Start:    $local_fs $remote_fs $network
# Required-Stop:     $local_fs $remote_fs $network
# Default-Start:     2 3 4 5
# Default-Stop:      0 1 6
# Short-Description: Start or stop the BubbleUPnP-daemon.
### END INIT INFO

PKG_NAME="BubbleUPnP"
PKG_DIR=/usr/local/AppCentral/bubbleupnp
RUN_AS="admin:administrators"
PID_FILE="$PKG_DIR/$PKG_NAME.pid"
CONFIG_DIR="$PKG_DIR/config"
REPOS_DIR="$PKG_DIR/repository"
if [ "x$JAVA_HOME" != "x" ]; then
    DAEMON="$JAVA_HOME/bin/java"
else
    DAEMON="java"
fi
# -Xss256k: thread stack size. 256K reduces per-thread memory usage and may prevent "java.lang.OutOfMemoryError: unable to create new native thread" on some systems
# -Djava.awt.headless=true: required for image transcoding to work on headless systems (eg no X-Window libraries)

DAEMON_OPTS=" -Xss256k -Djava.awt.headless=true -Djava.net.preferIPv4Stack=true -Dfile.encoding=UTF-8 -jar BubbleUPnPServerLauncher.jar -dataDir $CONFIG_DIR"

CheckPkgRunning() { #Is the PKG already running? if so, exit the script
      [ -f $PID_FILE ] && /sbin/start-stop-daemon -K --test -q -p $PID_FILE -x ${DAEMON} && /bin/echo " $PKG_NAME is already running" && exit 1
	#ok, we survived so the PKG should not be running
}

StartPkg(){ #starts the PKG
	/bin/echo -n "Starting $PKG_NAME"
	/bin/chown -R $RUN_AS $PKG_DIR
	/bin/chmod -R 766 $CONFIG_DIR # ensure admin has access to write to config dir.
	cd ${PKG_DIR}/BubbleServer
	/sbin/start-stop-daemon -S -n $PKG_NAME -p $PID_FILE -m -b -c $RUN_AS -x ${DAEMON} --${DAEMON_OPTS}
	/bin/echo " Done ($(/bin/date))"
}

ShutdownPkg() { #kills a proces based on a PID in a given PID file
	if [ -f $PID_FILE ] && /sbin/start-stop-daemon -K --test -q -p $PID_FILE -x ${DAEMON}; then
		#grab pid from pid file
		Pid=$(/bin/cat $PID_FILE)
		i=0
		/sbin/start-stop-daemon -K -q -p $PID_FILE -x ${DAEMON}
		/bin/echo -n " Waiting for ${PKG_NAME} to shut down: "
		while [ -d /proc/$Pid ]; do
			sleep 1
			let i+=1
			/bin/echo -n "$i, "
			if [ $i = 45 ]; then
				/bin/echo -n " Tired of waiting, killing ${PKG_NAME} now"
				/bin/kill -9 $Pid
				/bin/rm -f $PID_FILE
				/bin/echo " Done ($(/bin/date))"
				exit 1
			fi
		done
		/bin/rm -f $PID_FILE
		/bin/echo "Done ($(/bin/date))"
	else
		/bin/echo "${PKG_NAME} is not running? ($(/bin/date))"
	fi
}

case "$1" in
	start)
		/bin/echo "$PKG_NAME prestartup checks... ($(/bin/date))"	
		CheckPkgRunning  #Check if the PKG is not running, else exit
		StartPkg	 #Start the PKG... (finaly ;) )
	
	;;
	stop)
		/bin/echo "Shutting down ${PKG_NAME} at $(/bin/date)... "
		ShutdownPkg 	#shutdown the package
	;;
	restart)
		echo "Restarting $PKG_NAME"
		$0 stop
		$0 start
	;;
	*)
		echo "Usage: $0 {start|stop|restart}"
esac

exit 0